#### HEADER ================================================================
#
# [PURPOSE]
# Generate an NLME dataset
#
# [AUTHOR]
# Henning Schmidt
#
# [INPUT]
# Data in ../Output/01_importData/DAT01_GDF_raw.csv
#
# [OUTPUT]
# NLME PK dataset ../Data/01_dataNLME_PK/dataNLME.csv

## Preliminaries ====

rm(list = ls())
library(IQRtools)
IQRinitCompliance("SCRIPT_02_createNLMEdata.R")

# -------------------------------------------------------------------------#
# Load raw data in GDF
# -------------------------------------------------------------------------#

data <- IQRloadCSVdata("../Output/01_importData/DAT01_GDF_raw.csv")


# -------------------------------------------------------------------------#
# Import as GDF
# -------------------------------------------------------------------------#

dataGen <- IQRdataGENERAL(
  input     = data,
  doseNAMES = "HS0815 Dose",
  obsNAMES  = "HS0815 Concentration",

  cov0 = list(
    AGE0 = "Age",
    HT0  = "Height",
    WT0  = "Weight",
    ALB0 = "Albumin",
    CK0  = "Creatine Kinase"
  ),

  cat0 = list(
    SEXF = "Gender",
    RACE = "Race"
  )
)


# -------------------------------------------------------------------------#
# Clean Data
# -------------------------------------------------------------------------#

records <- list(
  "Pre-first-dose samples" = dataGen$IXGDF[dataGen$TIME<=0 & dataGen$NAME=="HS0815 Concentration"]
)

dataClean <- clean_IQRdataGENERAL(
  data          = dataGen,
  records       = records,
  FLAGrmPlacebo = TRUE,
  pathname      = "../Output/02_createNLMEdata/01_datacleaning"
)


# -------------------------------------------------------------------------#
# Get TRTNAME in ... usually already from source data ...
# -------------------------------------------------------------------------#

x <- dataClean[dataClean$EVID==1,c("USUBJID","DOSE","WT0")]
x <- x[!duplicated(x$USUBJID),]
x$DOSEMGKG <- signif(x$DOSE/x$WT0,1); x$DOSEMGKG[x$DOSEMGKG==4] <- 3; x$DOSEMGKG[x$DOSEMGKG==40] <- 30
x$TRTNAME <- paste0(x$DOSEMGKG," mg/kg")
dataClean$TRT <- NA
dataClean$TRTNAME <- NA
xx <- sapply(1:nrow(x), function (k) {
  dataClean$TRT[dataClean$USUBJID==x$USUBJID[k]] <<- x$DOSEMGKG[k]
  dataClean$TRTNAME[dataClean$USUBJID==x$USUBJID[k]] <<- x$TRTNAME[k]
})


# -------------------------------------------------------------------------#
# Check data
# -------------------------------------------------------------------------#

summary(dataClean)

# -------------------------------------------------------------------------#
# Export NLME data
# -------------------------------------------------------------------------#

exportNLME_IQRdataGENERAL(data = dataClean,
                          filename = "../Data/01_dataNLME_PK/dataNLME.csv",
                          FLAGxpt = TRUE,
                          FLAGdefine = FALSE)

# And a PDF define file in addition ... 
exportDEFINEpdf_IQRdataGENERAL(data = dataClean,datasetName = "dataNMLE",datasetLocation = "../Data/01_dataNLME_PK/dataNLME.xpt", filename = "../Data/01_dataNLME_PK/dataNLME_define.pdf")


